import path from 'path';
import fs from 'fs';
import sharp from 'sharp';
import fg from 'fast-glob';

const getFileName = (path2) => {
  return path2.replace(/(.*\/)*([^.]+).*/gi, "$2");
};
const getRelativePathName = (path2) => {
  const p = path2.split("/");
  if (p[0] === ".")
    p.shift();
  const f = p[p.length - 1].split(".");
  if (f.length >= 2)
    f.pop();
  p[p.length - 1] = f.join(".");
  const pathName = p.join("/");
  p.pop();
  return [pathName, p.join("/")];
};
const batSharp = async (options) => {
  const {
    inputArr = [],
    format = "png",
    outputPath,
    outputConfig = {},
    maintainRelativePath = true
  } = options || {};
  if (!outputPath || !inputArr?.length || !format)
    return;
  const entries = await fg(inputArr, { dot: true });
  console.log("input file list: ", entries);
  const isExist = fs.existsSync(path.normalize(outputPath));
  if (!isExist)
    fs.mkdirSync(outputPath);
  const res = await Promise.allSettled(entries.map(async (filePath) => {
    let targetPathName = "";
    if (maintainRelativePath) {
      const [pathName, pathWithoutName] = getRelativePathName(filePath);
      targetPathName = path.join(outputPath, `${pathName}.${format}`);
      const targetPath = path.join(outputPath, pathWithoutName);
      if (!fs.existsSync(path.normalize(targetPath)))
        fs.mkdirSync(targetPath);
    } else {
      targetPathName = path.join(outputPath, `${getFileName(filePath)}.${format}`);
    }
    await sharp(filePath)[format](outputConfig).toFile(targetPathName);
  }));
  const errors = res.filter((it) => it.status === "rejected");
  console.log(`${res.length - errors.length} tasks finished! Please check the path ${outputPath}.`);
  if (errors.length)
    console.error(errors.map((e) => e.reason));
};

export { batSharp };
